::: beignet.datasets.UniProtDataset
::: beignet.datasets.UniRef50Dataset
::: beignet.datasets.UniRef90Dataset
::: beignet.datasets.UniRef100Dataset
::: beignet.datasets.SwissProtDataset
::: beignet.datasets.TrEMBLDataset
